@@ -15,6 +15,7 @@ describe 'manila::db' do
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
         :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
 
     end
@@ -27,6 +28,7 @@ describe 'manila::db' do
           :database_max_pool_size  => '21',
           :database_max_retries    => '11',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
           :database_retry_interval => '11',
           :database_db_max_retries => '-1', }
       end
@@ -40,6 +42,7 @@ describe 'manila::db' do
         :max_retries    => '11',
         :retry_interval => '11',
         :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
 
     end
@@ -83,40 +86,34 @@ describe 'manila::db' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
-        :operatingsystemrelease => 'jessie',
-      })
-    end
-
-    it_configures 'manila::db'
-
+  shared_examples_for 'manila::db on Debian' do
     context 'using pymysql driver' do
       let :params do
         { :database_connection => 'mysql+pymysql://manila:manila@localhost/manila' }
       end
 
-      it { is_expected.to contain_package('db_backend_package').with({ :ensure => 'present', :name => 'python-pymysql', :tag=> 'openstack' }) }
+      it { is_expected.to contain_package('python-pymysql').with({ :ensure => 'present', :name => 'python-pymysql', :tag=> 'openstack' }) }
     end
   end
 
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat',
-        :operatingsystemrelease => '7.1',
-      })
-    end
-
-    it_configures 'manila::db'
-
+  shared_examples_for 'manila::db on RedHat' do
     context 'using pymysql driver' do
       let :params do
         { :database_connection => 'mysql+pymysql://manila:manila@localhost/manila' }
       end
 
-      it { is_expected.not_to contain_package('db_backend_package') }
+    end
+  end
+
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({ :fqdn => 'some.host.tld'}))
+      end
+      it_behaves_like 'manila::db'
+      it_behaves_like "manila::db on #{facts[:osfamily]}"
     end
   end
 
