@@ -27,23 +27,19 @@ describe 'manila::type_set' do
           'OS_USERNAME=admin',
           'OS_PASSWORD=asdf',
           'OS_AUTH_URL=http://127.127.127.1:5000/v2.0/'],
-        :require => 'Anchor[manila-support-package]')
+        :require => 'Anchor[manila::install::end]')
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      it_behaves_like 'manila types'
     end
-
-    it_configures 'manila types'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    it_configures 'manila types'
   end
 end
